%% Demo 2a - Phase contrast microscopy images / Single cell segmentation
%   reproduces the example in figure 1 in the paper
params = struct('useFillHoles', 1, 'minSegmAreaPx', 500, 'useFgrPropagation', 1, 'useNonMergingConstr', 1,...
                'debugMode', 1);

% using symmetric boundary costs         
params.lambda = 0.15;
params.binaryTermType = 'symmetric';
params.sigma = 0.008;
predLabels_symm = runTracking('demo/cell.tif','demo/model_PhC-C2DH-U373.mat', params);

% using asymmetric boundary costs    
params.lambda = 0.2;
params.binaryTermType = 'asymmetric-darkToBright';
params.sigma = 0.006;
predLabels_asymm = runTracking('demo/cell.tif','demo/model_PhC-C2DH-U373.mat', params);

% comparison (figure 1 in the paper)
im = im2double(imread('demo/cell.tif'));
load(['demo/cell_contour.mat'],'contour');
figure('units','normalized','outerposition',[0 0 1 1]);
subplot(1,3,1); imshow(im,[]); title('Raw image');
subplot(1,3,2); imshow(cat(3, im+0.4*contour, im+0.2*double(predLabels_symm(:,:,1)'>0)+0.4*contour, im+0.2*double(predLabels_symm(:,:,1)'>0)));
title('Graph cut segmentation'); xlabel('Symmetric boundary costs');
subplot(1,3,3); imshow(cat(3, im+0.2*double(predLabels_asymm(:,:,1)'>0)+0.4*contour, im+0.4*contour, im));
title('Graph cut segmentation'); xlabel('Asymmetric boundary costs / dark-to-bright preference');
